==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QStateMachine_SignalEvent_shell.cpp <==
#include "QStateMachine_SignalEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(statemachine)


void deleter_QStateMachine_SignalEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStateMachine::SignalEvent")
    QStateMachine::SignalEvent *_ptr = reinterpret_cast<QStateMachine::SignalEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStateMachine$SignalEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStateMachine$SignalEvent_shell) ); }

jmethodID QStateMachine$SignalEvent_shell::__shell_javaMethod(int pos) const { return QStateMachine$SignalEvent_shell::__shell()->javaMethod(typeid(QStateMachine::SignalEvent), pos); }

// emitting (writeShellConstructor)
QStateMachine$SignalEvent_shell::QStateMachine$SignalEvent_shell(QObject* sender0, int signalIndex1, const QList<QVariant>& arguments2)
    : QStateMachine::SignalEvent(sender0, signalIndex1, arguments2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStateMachine::SignalEvent::QStateMachine$SignalEvent_shell(QObject* sender0, int signalIndex1, const QList<QVariant>& arguments2)", QStateMachine$SignalEvent_shell::__shell())
    QStateMachine$SignalEvent_shell::__shell()->constructed(typeid(QStateMachine::SignalEvent));
}

// emitting (writeShellDestructor)
QStateMachine$SignalEvent_shell::~QStateMachine$SignalEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStateMachine::SignalEvent::~QStateMachine::SignalEvent()", QStateMachine$SignalEvent_shell::__shell())
    QStateMachine$SignalEvent_shell::__shell()->destructed(typeid(QStateMachine::SignalEvent));
}

void QStateMachine$SignalEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStateMachine$SignalEvent_shell*>(ptr)->QStateMachine$SignalEvent_shell::__shell()->tryDeleteShell(typeid(QStateMachine::SignalEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(statemachine)

// emitting (writeConstructors)
// new SignalEvent(QObject*,int,QList<QVariant>)
void __qt_construct_QStateMachine_SignalEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct SignalEvent(QObject*,int,QList<QVariant>)")
#if QT_CONFIG(statemachine)
    QtJambiScope __qtjambi_scope;
    jobject sender0 = __java_arguments[0].l;
    QObject* __qt_sender0 = qtjambi_cast<QObject* >(__jni_env, sender0);
    jint signalIndex1 = __java_arguments[1].i;
    Q_UNUSED(signalIndex1)
    jobject arguments2 = __java_arguments[2].l;
    const QList<QVariant>&  __qt_arguments2 = qtjambi_cast<const QList<QVariant>& >(__jni_env, __qtjambi_scope, arguments2);
    QStateMachine::SignalEvent *__qt_this = new(__qtjambi_ptr) QStateMachine$SignalEvent_shell(__qt_sender0, static_cast<int>(signalIndex1), __qt_arguments2);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
}

// destruct QStateMachine$SignalEvent_shell
void __qt_destruct_QStateMachine_SignalEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStateMachine::SignalEvent")

#if QT_CONFIG(statemachine)

    reinterpret_cast<QStateMachine$SignalEvent_shell*>(ptr)->~QStateMachine$SignalEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(statemachine)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStateMachine::SignalEvent::SignalEvent(QObject*,int,QList<QVariant>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_initialize_1native__Lio_qt_core_QStateMachine_00024SignalEvent_2Lio_qt_core_QObject_2ILjava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject sender0,
 jint signalIndex1,
 jobject arguments2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStateMachine::SignalEvent::SignalEvent(QObject*,int,QList<QVariant>)")
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        jvalue arguments[3];
        arguments[0].l = sender0;
        arguments[1].i = signalIndex1;
        arguments[2].l = arguments2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStateMachine_SignalEvent_0, sizeof(QStateMachine$SignalEvent_shell), typeid(QStateMachine::SignalEvent), true, &deleter_QStateMachine_SignalEvent, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(sender0)
        Q_UNUSED(signalIndex1)
        Q_UNUSED(arguments2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStateMachine::SignalEvent::arguments()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_arguments_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::arguments()const", __qt_this)
        QList<QVariant> __qt_return_value = __qt_this->arguments();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStateMachine::SignalEvent::sender()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_sender_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::sender()const", __qt_this)
        QObject* __qt_return_value = __qt_this->sender();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStateMachine::SignalEvent::signalIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_signalIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::signalIndex()const", __qt_this)
        __java_return_value = __qt_this->signalIndex();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(statemachine)

        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QStateMachine::SignalEvent(*__qt_this));

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(statemachine)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStateMachine_SignalEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(statemachine)

    const std::type_info& typeId = registerObjectTypeInfo<QStateMachine::SignalEvent>("QStateMachine::SignalEvent", "io/qt/core/QStateMachine$SignalEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStateMachine_SignalEvent, {
        ConstructorInfo(&__qt_construct_QStateMachine_SignalEvent_0, "Lio/qt/core/QObject;ILjava/util/Collection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStateMachine_SignalEvent);
    registerSizeOfShell(typeId, sizeof(QStateMachine$SignalEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QStateMachine::SignalEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(statemachine)

}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QStateMachine_SignalEvent_shell.cpp <==
#include "QStateMachine_SignalEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(statemachine)


void deleter_QStateMachine_SignalEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStateMachine::SignalEvent")
    QStateMachine::SignalEvent *_ptr = reinterpret_cast<QStateMachine::SignalEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStateMachine$SignalEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStateMachine$SignalEvent_shell) ); }

jmethodID QStateMachine$SignalEvent_shell::__shell_javaMethod(int pos) const { return QStateMachine$SignalEvent_shell::__shell()->javaMethod(typeid(QStateMachine::SignalEvent), pos); }

// emitting (writeShellConstructor)
QStateMachine$SignalEvent_shell::QStateMachine$SignalEvent_shell(QObject* sender0, int signalIndex1, const QList<QVariant>& arguments2)
    : QStateMachine::SignalEvent(sender0, signalIndex1, arguments2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStateMachine::SignalEvent::QStateMachine$SignalEvent_shell(QObject* sender0, int signalIndex1, const QList<QVariant>& arguments2)", QStateMachine$SignalEvent_shell::__shell())
    QStateMachine$SignalEvent_shell::__shell()->constructed(typeid(QStateMachine::SignalEvent));
}

QStateMachine$SignalEvent_shell::QStateMachine$SignalEvent_shell(const QStateMachine::SignalEvent& other0)
    : QStateMachine::SignalEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStateMachine::SignalEvent::QStateMachine$SignalEvent_shell(const QStateMachine::SignalEvent& other0)", QStateMachine$SignalEvent_shell::__shell())
    QStateMachine$SignalEvent_shell::__shell()->constructed(typeid(QStateMachine::SignalEvent));
}

// emitting (writeShellDestructor)
QStateMachine$SignalEvent_shell::~QStateMachine$SignalEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStateMachine::SignalEvent::~QStateMachine::SignalEvent()", QStateMachine$SignalEvent_shell::__shell())
    QStateMachine$SignalEvent_shell::__shell()->destructed(typeid(QStateMachine::SignalEvent));
}

void QStateMachine$SignalEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStateMachine$SignalEvent_shell*>(ptr)->QStateMachine$SignalEvent_shell::__shell()->tryDeleteShell(typeid(QStateMachine::SignalEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(statemachine)

// emitting (writeConstructors)
// new SignalEvent(QObject*,int,QList<QVariant>)
void __qt_construct_QStateMachine_SignalEvent_QObject_ptr_int_cref_QList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct SignalEvent(QObject*,int,QList<QVariant>)")
#if QT_CONFIG(statemachine)
    QtJambiScope __qtjambi_scope;
    jobject sender0 = __java_arguments[0].l;
    QObject* __qt_sender0 = qtjambi_cast<QObject* >(__jni_env, sender0);
    jint signalIndex1 = __java_arguments[1].i;
    Q_UNUSED(signalIndex1)
    jobject arguments2 = __java_arguments[2].l;
    const QList<QVariant>&  __qt_arguments2 = qtjambi_cast<const QList<QVariant>& >(__jni_env, __qtjambi_scope, arguments2);
    QStateMachine::SignalEvent *__qt_this = new(__qtjambi_ptr) QStateMachine$SignalEvent_shell(__qt_sender0, static_cast<int>(signalIndex1), __qt_arguments2);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
}

// QStateMachine::SignalEvent::SignalEvent(QObject*,int,QList<QVariant>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_initialize_1native__Lio_qt_core_QStateMachine_00024SignalEvent_2Lio_qt_core_QObject_2ILjava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject sender0,
 jint signalIndex1,
 jobject arguments2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStateMachine::SignalEvent::SignalEvent(QObject*,int,QList<QVariant>)")
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        jvalue arguments[3];
        arguments[0].l = sender0;
        arguments[1].i = signalIndex1;
        arguments[2].l = arguments2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStateMachine_SignalEvent_QObject_ptr_int_cref_QList, sizeof(QStateMachine$SignalEvent_shell), typeid(QStateMachine::SignalEvent), true, &deleter_QStateMachine_SignalEvent, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(sender0)
        Q_UNUSED(signalIndex1)
        Q_UNUSED(arguments2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new SignalEvent(QStateMachine::SignalEvent)
void __qt_construct_QStateMachine_SignalEvent_cref_QStateMachine_SignalEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct SignalEvent(QStateMachine::SignalEvent)")
#if QT_CONFIG(statemachine)
    jobject other0 = __java_arguments[0].l;
    const QStateMachine::SignalEvent& __qt_other0 = qtjambi_cast<const QStateMachine::SignalEvent& >(__jni_env, other0);
    QStateMachine::SignalEvent *__qt_this = new(__qtjambi_ptr) QStateMachine$SignalEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
}

// QStateMachine::SignalEvent::SignalEvent(QStateMachine::SignalEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_initialize_1native__Lio_qt_core_QStateMachine_00024SignalEvent_2Lio_qt_core_QStateMachine_00024SignalEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStateMachine::SignalEvent::SignalEvent(QStateMachine::SignalEvent)")
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStateMachine_SignalEvent_cref_QStateMachine_SignalEvent, sizeof(QStateMachine$SignalEvent_shell), typeid(QStateMachine::SignalEvent), true, &deleter_QStateMachine_SignalEvent, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStateMachine$SignalEvent_shell
void __qt_destruct_QStateMachine_SignalEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStateMachine::SignalEvent")

#if QT_CONFIG(statemachine)

    reinterpret_cast<QStateMachine$SignalEvent_shell*>(ptr)->~QStateMachine$SignalEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(statemachine)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStateMachine::SignalEvent::arguments()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_arguments_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::arguments()const", __qt_this)
        QList<QVariant> __qt_return_value = __qt_this->arguments();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStateMachine::SignalEvent::sender()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_sender_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::sender()const", __qt_this)
        QObject* __qt_return_value = __qt_this->sender();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStateMachine::SignalEvent::signalIndex()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_signalIndex_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(statemachine)
        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStateMachine::SignalEvent::signalIndex()const", __qt_this)
        __java_return_value = __qt_this->signalIndex();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(statemachine)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QStateMachine_00024SignalEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(statemachine)

        const QStateMachine::SignalEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStateMachine::SignalEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QStateMachine::SignalEvent(*__qt_this));

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(statemachine)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStateMachine_SignalEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(statemachine)

    const std::type_info& typeId = registerObjectTypeInfo<QStateMachine::SignalEvent>("QStateMachine::SignalEvent", "io/qt/core/QStateMachine$SignalEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStateMachine_SignalEvent, {
        ConstructorInfo(&__qt_construct_QStateMachine_SignalEvent_QObject_ptr_int_cref_QList, "Lio/qt/core/QObject;ILjava/util/Collection;")
       ,ConstructorInfo(&__qt_construct_QStateMachine_SignalEvent_cref_QStateMachine_SignalEvent, "Lio/qt/core/QStateMachine$SignalEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStateMachine_SignalEvent);
    registerSizeOfShell(typeId, sizeof(QStateMachine$SignalEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QStateMachine::SignalEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(statemachine)

}
